pub struct FrontendChannels {
pub event_rx: Receiver<AgentEvent>,
pub message_tx: Sender<FrontendMessage>,
}Expand description
Frontend-side channel ends.
Fields
event_rx: Receiver<AgentEvent>Frontend uses this to receive events from the Agent.
message_tx: Sender<FrontendMessage>Frontend uses this to send messages to the Agent.